@@ -8,6 +8,8 @@
 
 #pragma once
 
+#include <fizz/crypto/Hmac.h>
+
 namespace fizz {
 namespace openssl {
 
@@ -22,13 +24,23 @@ void Sha<T>::hash_update(folly::ByteRange data) {
 }
 
 template <typename T>
-void Sha<T>::hash_update(const folly::IOBuf& data) {
-  digest_.hash_update(data);
+void Sha<T>::hash_final(folly::MutableByteRange out) {
+  digest_.hash_final(out);
 }
 
 template <typename T>
-void Sha<T>::hash_final(folly::MutableByteRange out) {
-  digest_.hash_final(out);
+std::unique_ptr<fizz::Hasher> Sha<T>::clone() const {
+  return std::make_unique<Sha<T>>(*this);
+}
+
+template <typename T>
+size_t Sha<T>::getHashLen() const {
+  return T::HashLen;
+}
+
+template <typename T>
+inline size_t Sha<T>::getBlockSize() const {
+  return T::BlockSize;
 }
 
 template <typename T>
@@ -36,14 +48,23 @@ void Sha<T>::hmac(
     folly::ByteRange key,
     const folly::IOBuf& in,
     folly::MutableByteRange out) {
-  CHECK_GE(out.size(), T::HashLen);
-  folly::ssl::OpenSSLHash::hmac(out, T::HashEngine(), key, in);
+  fizz::hmac(
+      []() -> std::unique_ptr<fizz::Hasher> {
+        return std::make_unique<Sha<T>>();
+      },
+      key,
+      in,
+      out);
 }
 
 template <typename T>
 void Sha<T>::hash(const folly::IOBuf& in, folly::MutableByteRange out) {
-  CHECK_GE(out.size(), T::HashLen);
-  folly::ssl::OpenSSLHash::hash(out, T::HashEngine(), in);
+  fizz::hash(
+      []() -> std::unique_ptr<fizz::Hasher> {
+        return std::make_unique<Sha<T>>();
+      },
+      in,
+      out);
 }
 } // namespace openssl
 } // namespace fizz
