@@ -11,8 +11,8 @@
 #include <fizz/compression/BrotliCertificateCompressor.h>
 #include <fizz/compression/BrotliCertificateDecompressor.h>
 #include <fizz/crypto/Utils.h>
+#include <fizz/protocol/test/CertUtil.h>
 #include <fizz/protocol/test/Matchers.h>
-#include <fizz/protocol/test/Utilities.h>
 #include <fizz/record/Extensions.h>
 
 using namespace folly;
@@ -65,7 +65,7 @@ class BrotliCertificateCompressorTest : public testing::Test {
   template <class T>
   std::string encodeHex(T&& msg) {
     auto buf = encode(std::forward<T>(msg));
-    auto str = buf->moveToFbString().toStdString();
+    auto str = buf->template to<std::string>();
     return hexlify(str);
   }
   std::unique_ptr<BrotliCertificateCompressor> compressor_;
