@@ -39,6 +39,18 @@ struct ChaCha20Poly1305 {
   static const size_t kTagLength{16};
 };
 
+struct AEGIS128L {
+  static const size_t kKeyLength{16};
+  static const size_t kIVLength{16};
+  static const size_t kTagLength{16};
+};
+
+struct AEGIS256 {
+  static const size_t kKeyLength{32};
+  static const size_t kIVLength{32};
+  static const size_t kTagLength{16};
+};
+
 // Hashing Algorithms
 // Please update HASH_MAX_BLOCK_SIZE if necessary if adding support for more
 // hashes.
@@ -86,8 +98,23 @@ struct P521 {
   static constexpr int keyShareLength = coordinateLength * 2 + 1;
 };
 
+struct X25519 {};
+
+// KEMs
+struct Kyber512 {};
+struct Kyber768 {};
+
+constexpr size_t kEcMaxPublicKeyshareLength =
+    256; // The max possible size of a buffer storing an EC keyshare. Please
+         // keep this definition in close proximity to the EC Curve tag types.
+
+constexpr size_t kEcMaxSharedSecretLength =
+    256; // The max possible size of a buffer storing an EC shared secret.
+         // Please keep this definition in close proximity to the tag types.
+
+enum class KeyType { RSA, P256, P384, P521, ED25519 };
+
 using HashFunc = void (*)(const folly::IOBuf&, folly::MutableByteRange);
 using HmacFunc =
     void (*)(folly::ByteRange, const folly::IOBuf&, folly::MutableByteRange);
-
 } // namespace fizz
