@@ -64,7 +64,8 @@ DHKEM getDHKEM(std::unique_ptr<KeyExchange> actualKex, NamedGroup group) {
   auto prefix = "HPKE-v1";
   auto hkdf = std::make_unique<fizz::hpke::Hkdf>(
       folly::IOBuf::copyBuffer(prefix),
-      std::make_unique<HkdfImpl>(HkdfImpl::create<Sha256>()));
+      std::make_unique<HkdfImpl>(
+          HkdfImpl(Sha256::HashLen, &openssl::Hasher<Sha256>::hmac)));
   return DHKEM(
       std::make_unique<MockKeyExchange>(std::move(actualKex)),
       group,
