@@ -10,6 +10,7 @@
 #include <folly/portability/GTest.h>
 
 #include <fizz/extensions/delegatedcred/DelegatedCredentialCertManager.h>
+
 #include <fizz/extensions/delegatedcred/test/Mocks.h>
 
 #include <fizz/protocol/test/Mocks.h>
@@ -88,11 +89,11 @@ TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestNoMatchDefault) {
       DelegatedCredentialCertManagerTest::getCert("blah.com", {}, kRsa);
   auto cert2 =
       DelegatedCredentialCertManagerTest::getCert("blah.com", {}, kRsa);
-  DelegatedCredentialCertManagerTest::manager_.addCert(cert1, true);
+  DelegatedCredentialCertManagerTest::manager_.addCertAndSetDefault(cert1);
   // Technically, the default flag doesn't really apply to DC certs.
   // It should always return the undelegated default cert if an exact
   // match can't be found..
-  DelegatedCredentialCertManagerTest::manager_.addCert(cert2, true);
+  DelegatedCredentialCertManagerTest::manager_.addCertAndSetDefault(cert2);
   auto res = DelegatedCredentialCertManagerTest::manager_.getCert(
       std::string("test.com"), kRsa, kRsa, TypeParam::Extensions());
   EXPECT_EQ(res->cert, cert1);
@@ -100,7 +101,7 @@ TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestNoMatchDefault) {
 
 TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestNoSniDefault) {
   auto cert = DelegatedCredentialCertManagerTest::getCert("blah.com", {}, kRsa);
-  DelegatedCredentialCertManagerTest::manager_.addCert(cert, true);
+  DelegatedCredentialCertManagerTest::manager_.addCertAndSetDefault(cert);
   auto res = DelegatedCredentialCertManagerTest::manager_.getCert(
       folly::none, kRsa, kRsa, TypeParam::Extensions());
   EXPECT_EQ(res->cert, cert);
@@ -109,7 +110,7 @@ TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestNoSniDefault) {
 TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestWildcardDefault) {
   auto cert =
       DelegatedCredentialCertManagerTest::getCert("*.blah.com", {}, kRsa);
-  DelegatedCredentialCertManagerTest::manager_.addCert(cert, true);
+  DelegatedCredentialCertManagerTest::manager_.addCertAndSetDefault(cert);
   auto res = DelegatedCredentialCertManagerTest::manager_.getCert(
       folly::none, kRsa, kRsa, TypeParam::Extensions());
   EXPECT_EQ(res->cert, cert);
@@ -117,7 +118,7 @@ TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestWildcardDefault) {
 
 TYPED_TEST(DelegatedCredentialCertManagerTestTyped, TestUppercaseDefault) {
   auto cert = DelegatedCredentialCertManagerTest::getCert("BLAH.com", {}, kRsa);
-  DelegatedCredentialCertManagerTest::manager_.addCert(cert, true);
+  DelegatedCredentialCertManagerTest::manager_.addCertAndSetDefault(cert);
   auto res = DelegatedCredentialCertManagerTest::manager_.getCert(
       folly::none, kRsa, kRsa, TypeParam::Extensions());
   EXPECT_EQ(res->cert, cert);
@@ -417,7 +418,7 @@ TEST_F(DelegatedCredentialCertManagerTest, TestUndelegatedNeverGetsCredential) {
 
   manager_.addCert(cert1);
   manager_.addCert(cert2);
-  manager_.addCert(cert3, true);
+  manager_.addCertAndSetDefault(cert3);
 
   res = manager_.getCert(host1, kRsa, kRsa, {});
   EXPECT_EQ(res->cert, cert1);
@@ -455,7 +456,7 @@ TEST_F(
 
   manager_.addCert(cert1);
   manager_.addCert(cert2);
-  manager_.addCert(cert3, true);
+  manager_.addCertAndSetDefault(cert3);
 
   auto res = manager_.getCert(host1, kRsa, kRsa, DelegatedMode::Extensions());
   EXPECT_EQ(res->cert, cert1);
@@ -498,6 +499,30 @@ TEST_F(
       DelegatedMode::Extensions({SignatureScheme::rsa_pss_sha512}));
   EXPECT_EQ(res->cert, cert1);
 }
+
+TEST_F(DelegatedCredentialCertManagerTest, TestDelegatedMatchWithDefaultSet) {
+  auto cert1 = getCert("foo.test.com", {}, kRsa);
+  auto cert2 = getCredential("foo.test.com", {}, kRsa);
+  manager_.addCertAndSetDefault(cert1);
+  manager_.addDelegatedCredentialAndSetDefault(cert2);
+
+  auto res = manager_.getCert(
+      std::string("foo_blah"), kRsa, kRsa, DelegatedMode::Extensions());
+  EXPECT_EQ(res->cert, cert2);
+}
+
+TEST_F(
+    DelegatedCredentialCertManagerTest,
+    TestDelegatedNotMatchedWithDefaultNotSet) {
+  auto cert1 = getCert("foo.test.com", {}, kRsa);
+  auto cert2 = getCredential("foo.test.com", {}, kRsa);
+  manager_.addCertAndSetDefault(cert1);
+  manager_.addDelegatedCredential(cert2);
+
+  auto res = manager_.getCert(
+      std::string("foo_blah"), kRsa, kRsa, DelegatedMode::Extensions());
+  EXPECT_EQ(res->cert, cert1);
+}
 } // namespace test
 } // namespace extensions
 } // namespace fizz
