@@ -13,14 +13,15 @@
 
 namespace fizz {
 template <>
-inline Extension encodeExtension(const ech::ClientECH& clientECH) {
+inline Extension encodeExtension(const ech::OuterECHClientHello& clientECH) {
   Extension ext;
   ext.extension_type = ExtensionType::encrypted_client_hello;
   ext.extension_data = folly::IOBuf::create(0);
 
   folly::io::Appender appender(ext.extension_data.get(), 20);
+  detail::write(clientECH.ech_type, appender);
   detail::write(clientECH.cipher_suite, appender);
-  detail::writeBuf<uint8_t>(clientECH.config_id, appender);
+  detail::write(clientECH.config_id, appender);
   detail::writeBuf<uint16_t>(clientECH.enc, appender);
   detail::writeBuf<uint16_t>(clientECH.payload, appender);
 
@@ -28,7 +29,7 @@ inline Extension encodeExtension(const ech::ClientECH& clientECH) {
 }
 
 template <>
-inline Extension encodeExtension(const ech::ServerECH& serverECH) {
+inline Extension encodeExtension(const ech::ECHEncryptedExtensions& serverECH) {
   Extension ext;
   ext.extension_type = ExtensionType::encrypted_client_hello;
   ext.extension_data = folly::IOBuf::create(0);
@@ -40,10 +41,13 @@ inline Extension encodeExtension(const ech::ServerECH& serverECH) {
 }
 
 template <>
-inline Extension encodeExtension(const ech::ECHIsInner&) {
+inline Extension encodeExtension(const ech::InnerECHClientHello& innerECH) {
   Extension ext;
-  ext.extension_type = ExtensionType::ech_is_inner;
+  ext.extension_type = ExtensionType::encrypted_client_hello;
   ext.extension_data = folly::IOBuf::create(0);
+
+  folly::io::Appender appender(ext.extension_data.get(), 4);
+  detail::write(innerECH.ech_type, appender);
   return ext;
 }
 
@@ -60,10 +64,27 @@ inline Extension encodeExtension(const ech::OuterExtensions& outerExts) {
 }
 
 template <>
-inline ech::ClientECH getExtension(folly::io::Cursor& cs) {
-  ech::ClientECH clientECH;
+inline Extension encodeExtension(const ech::ECHHelloRetryRequest& conf) {
+  Extension ext;
+  ext.extension_type = ExtensionType::encrypted_client_hello;
+  ext.extension_data = folly::IOBuf::create(8);
+
+  folly::io::Appender appender(ext.extension_data.get(), 0);
+  appender.push(conf.confirmation.data(), conf.confirmation.size());
+
+  return ext;
+}
+
+template <>
+inline ech::OuterECHClientHello getExtension(folly::io::Cursor& cs) {
+  ech::ECHClientHelloType type;
+  detail::read(type, cs);
+  if (type != ech::ECHClientHelloType::Outer) {
+    throw std::runtime_error("wrong ech variant");
+  }
+  ech::OuterECHClientHello clientECH;
   detail::read(clientECH.cipher_suite, cs);
-  detail::readBuf<uint8_t>(clientECH.config_id, cs);
+  detail::read(clientECH.config_id, cs);
   detail::readBuf<uint16_t>(clientECH.enc, cs);
   detail::readBuf<uint16_t>(clientECH.payload, cs);
 
@@ -71,16 +92,21 @@ inline ech::ClientECH getExtension(folly::io::Cursor& cs) {
 }
 
 template <>
-inline ech::ServerECH getExtension(folly::io::Cursor& cs) {
-  ech::ServerECH serverECH;
+inline ech::ECHEncryptedExtensions getExtension(folly::io::Cursor& cs) {
+  ech::ECHEncryptedExtensions serverECH;
   detail::readVector<uint16_t>(serverECH.retry_configs, cs);
 
   return serverECH;
 }
 
 template <>
-inline ech::ECHIsInner getExtension(folly::io::Cursor&) {
-  return ech::ECHIsInner();
+inline ech::InnerECHClientHello getExtension(folly::io::Cursor& cs) {
+  ech::ECHClientHelloType type;
+  detail::read(type, cs);
+  if (type != ech::ECHClientHelloType::Inner) {
+    throw std::runtime_error("wrong ech variant");
+  }
+  return ech::InnerECHClientHello();
 }
 
 template <>
@@ -89,4 +115,16 @@ inline ech::OuterExtensions getExtension(folly::io::Cursor& cs) {
   detail::readVector<uint8_t>(outerExts.types, cs);
   return outerExts;
 }
+
+template <>
+inline ech::ECHHelloRetryRequest getExtension(folly::io::Cursor& cs) {
+  ech::ECHHelloRetryRequest conf;
+  if (cs.totalLength() != conf.confirmation.size()) {
+    throw FizzException(
+        "ECHHelloRetryRequest confirmation wrong size",
+        AlertDescription::decode_error);
+  }
+  cs.pull(conf.confirmation.data(), conf.confirmation.size());
+  return conf;
+}
 } // namespace fizz
