@@ -148,9 +148,8 @@ folly::Optional<SupportedECHConfig> selectECHConfig(
       }
 
       // Check for an invalid public name and skip if found.
-      std::string publicName = echConfig.public_name->cloneCoalescedAsValue()
-                                   .moveToFbString()
-                                   .toStdString();
+      std::string publicName =
+          echConfig.public_name->cloneCoalescedAsValue().to<std::string>();
       if (!isValidPublicName(publicName)) {
         VLOG(8) << publicName << " isn't a valid public name";
         continue;
@@ -505,18 +504,57 @@ size_t calculateECHPadding(
   return padding;
 }
 
+std::vector<Extension> generateAndReplaceOuterExtensions(
+    std::vector<Extension>&& chloInnerExt,
+    const std::vector<ExtensionType>& outerExtensionTypes) {
+  std::vector<ExtensionType> extTypes;
+  for (const auto& ext : chloInnerExt) {
+    if (std::find(
+            outerExtensionTypes.begin(),
+            outerExtensionTypes.end(),
+            ext.extension_type) != outerExtensionTypes.end()) {
+      extTypes.push_back(ext.extension_type);
+    }
+  }
+  if (extTypes.size() == 0) {
+    return std::move(chloInnerExt);
+  }
+
+  OuterExtensions outerExt;
+  outerExt.types = extTypes;
+
+  bool outerExtensionsInserted = false;
+  for (const auto extType : extTypes) {
+    auto it = std::find_if(
+        chloInnerExt.begin(), chloInnerExt.end(), [extType](const auto& ext) {
+          return ext.extension_type == extType;
+        });
+    if (!outerExtensionsInserted) {
+      *it = encodeExtension(outerExt);
+      outerExtensionsInserted = true;
+    } else {
+      chloInnerExt.erase(it);
+    }
+  }
+
+  return std::move(chloInnerExt);
+}
+
 namespace {
 
-void encryptClientHelloShared(
+void encryptClientHelloImpl(
     OuterECHClientHello& echExtension,
     const ClientHello& clientHelloInner,
     const ClientHello& clientHelloOuter,
     hpke::SetupResult& setupResult,
     const folly::Optional<ClientPresharedKey>& greasePsk,
-    size_t maxLen) {
+    size_t maxLen,
+    const std::vector<ExtensionType>& outerExtensionTypes) {
   // Remove legacy_session_id and serialize the client hello inner
   auto chloInnerCopy = clientHelloInner.clone();
   chloInnerCopy.legacy_session_id = folly::IOBuf::copyBuffer("");
+  chloInnerCopy.extensions = generateAndReplaceOuterExtensions(
+      std::move(chloInnerCopy.extensions), outerExtensionTypes);
   auto encodedClientHelloInner = encode(chloInnerCopy);
 
   size_t padding = calculateECHPadding(
@@ -563,20 +601,22 @@ OuterECHClientHello encryptClientHelloHRR(
     const ClientHello& clientHelloInner,
     const ClientHello& clientHelloOuter,
     hpke::SetupResult& setupResult,
-    const folly::Optional<ClientPresharedKey>& greasePsk) {
+    const folly::Optional<ClientPresharedKey>& greasePsk,
+    const std::vector<ExtensionType>& outerExtensionTypes) {
   // Create ECH extension with blank config ID and enc for HRR
   OuterECHClientHello echExtension;
   echExtension.cipher_suite = supportedConfig.cipherSuite;
   echExtension.config_id = supportedConfig.configId;
   echExtension.enc = folly::IOBuf::create(0);
 
-  encryptClientHelloShared(
+  encryptClientHelloImpl(
       echExtension,
       clientHelloInner,
       clientHelloOuter,
       setupResult,
       greasePsk,
-      supportedConfig.maxLen);
+      supportedConfig.maxLen,
+      outerExtensionTypes);
 
   return echExtension;
 }
@@ -586,20 +626,22 @@ OuterECHClientHello encryptClientHello(
     const ClientHello& clientHelloInner,
     const ClientHello& clientHelloOuter,
     hpke::SetupResult& setupResult,
-    const folly::Optional<ClientPresharedKey>& greasePsk) {
+    const folly::Optional<ClientPresharedKey>& greasePsk,
+    const std::vector<ExtensionType>& outerExtensionTypes) {
   // Create ECH extension
   OuterECHClientHello echExtension;
   echExtension.cipher_suite = supportedConfig.cipherSuite;
   echExtension.config_id = supportedConfig.configId;
   echExtension.enc = setupResult.enc->clone();
 
-  encryptClientHelloShared(
+  encryptClientHelloImpl(
       echExtension,
       clientHelloInner,
       clientHelloOuter,
       setupResult,
       greasePsk,
-      supportedConfig.maxLen);
+      supportedConfig.maxLen,
+      outerExtensionTypes);
 
   return echExtension;
 }
@@ -681,8 +723,8 @@ std::unique_ptr<hpke::HpkeContext> setupDecryptionContext(
 }
 
 std::vector<Extension> substituteOuterExtensions(
-    std::vector<Extension>&& innerExt,
-    const std::vector<Extension>& outerExt) {
+    std::vector<Extension>&& chloInnerExt,
+    const std::vector<Extension>& chloOuterExt) {
   std::vector<Extension> expandedInnerExt;
 
   // This will throw if we duplicate an extension (or if we try to put an
@@ -695,7 +737,7 @@ std::vector<Extension> substituteOuterExtensions(
     seenTypes.insert(t);
   };
 
-  for (auto& ext : innerExt) {
+  for (auto& ext : chloInnerExt) {
     dupeCheck(ext.extension_type);
     if (ExtensionType::ech_outer_extensions != ext.extension_type) {
       expandedInnerExt.push_back(std::move(ext));
@@ -710,8 +752,8 @@ std::vector<Extension> substituteOuterExtensions(
       }
 
       // Use the linear approach suggested by the RFC.
-      auto outerIt = outerExt.cbegin();
-      auto outerEnd = outerExt.cend();
+      auto outerIt = chloOuterExt.cbegin();
+      auto outerEnd = chloOuterExt.cend();
       for (const auto extType : outerExtensions.types) {
         // Check types for dupes and ech
         dupeCheck(extType);
