@@ -215,6 +215,20 @@ class MockCertificateVerifier : public CertificateVerifier {
       (const));
 };
 
+class MockCertificateSerialization : public CertificateSerialization {
+ public:
+  MOCK_METHOD(
+      std::unique_ptr<folly::IOBuf>,
+      serialize,
+      (const fizz::Cert&),
+      (const));
+  MOCK_METHOD(
+      std::shared_ptr<const fizz::Cert>,
+      deserialize,
+      (folly::ByteRange),
+      (const));
+};
+
 class MockFactory : public ::fizz::DefaultFactory {
  public:
   MOCK_METHOD(
@@ -250,7 +264,7 @@ class MockFactory : public ::fizz::DefaultFactory {
   MOCK_METHOD(
       std::unique_ptr<KeyExchange>,
       makeKeyExchange,
-      (NamedGroup group, Factory::KeyExchangeMode mode),
+      (NamedGroup group, KeyExchangeRole role),
       (const));
   MOCK_METHOD(std::unique_ptr<Aead>, makeAead, (CipherSuite cipher), (const));
   MOCK_METHOD(Random, makeRandom, (), (const));
@@ -343,7 +357,7 @@ class MockAsyncKexFactory : public ::fizz::DefaultFactory {
   MOCK_METHOD(
       std::unique_ptr<KeyExchange>,
       makeKeyExchange,
-      (NamedGroup group, Factory::KeyExchangeMode mode),
+      (NamedGroup group, KeyExchangeRole role),
       (const));
 };
 
