@@ -472,7 +472,8 @@ class BasicPersistentPskCache : public BasicPskCache {
     if (saveFile_.empty()) {
       return;
     }
-    std::string serializedPsk = serializePsk(psk);
+    std::string serializedPsk =
+        serializePsk(fizz::openssl::certificateSerializer(), psk);
     if (writeFile(serializedPsk, saveFile_.c_str())) {
       LOG(INFO) << "\n Saved PSK to " << saveFile_ << " \n";
     } else {
@@ -488,7 +489,8 @@ class BasicPersistentPskCache : public BasicPskCache {
     std::string serializedPsk;
     readFile(loadFile_.c_str(), serializedPsk);
     try {
-      return deserializePsk(serializedPsk, DefaultFactory());
+      return deserializePsk(
+          fizz::openssl::certificateSerializer(), serializedPsk);
     } catch (const std::exception& e) {
       LOG(ERROR) << "Error deserializing: " << loadFile_ << "\n" << e.what();
       throw;
